@@ -1,5 +1,6 @@
 import logging
 from pathlib import Path
+import textwrap
 
 logger = logging.getLogger(__name__)
 
@@ -11,7 +12,17 @@ DEFAULT_SETTINGS = {
     "FONT_FILENAME": "Arial.ttf",
     "FONT_SIZE": 70,
     "FONT_FILL": "#000000",
+    "CANVAS_HEIGHT": 630,
+    "CANVAS_WIDTH": 1200,
+    "CANVAS_LEFT": 0,
+    "CANVAS_TOP": 0,
+    "LEADING": 15,
+    "WRAPPING_FUNCTION": textwrap.wrap,
+    "CHARS_PER_LINE": 30,
     "KEY_NAME": "og_image",
+    "INCLUDE_SITEURL": False,
+    "INCLUDE_DRAFTS": False,
+    "INCLUDE_HIDDEN": False,
     "configured": False,
 }
 
@@ -41,9 +52,13 @@ def populate_plugin_settings(pelican_instance):
     content_path = Path(pelican_instance.settings.get("PATH"))
     PLUGIN_SETTINGS["PATH"] = content_path / PLUGIN_SETTINGS["PATH"]
 
-    try:
-        PLUGIN_SETTINGS["FONT_SIZE"] = int(PLUGIN_SETTINGS["FONT_SIZE"])
-    except ValueError:
-        logger.error("SOCIAL_CARDS_FONT_SIZE must be a number")
+    int_settings = [
+        key for key, value in DEFAULT_SETTINGS.items() if isinstance(value, int)
+    ]
+    for key in int_settings:
+        try:
+            PLUGIN_SETTINGS[key] = int(PLUGIN_SETTINGS[key])
+        except ValueError:
+            logger.error(f"SOCIAL_CARDS_{key} must be a number")
 
     logger.debug(f"pelican.plugins.social_cards settings: {PLUGIN_SETTINGS}")
